#'
#' Figure 4
#'

library(tidyverse)
library(ggpubr)

samples = read_tsv('../tmp/samples.txt', comment = '#')
mutations = read_tsv('../tmp/mutations.txt', comment = '#')
cancer_types = read_tsv('../tmp/cancer_types.txt', comment = '#')
variants = read_tsv('../tmp/variants.txt', comment = '#')
classes = read_tsv('../tmp/classes.txt', comment = '#', col_types = cols(.default = 'c'))

relevant_variants = variants %>% filter(class != '?' | count >= 5) %>% pull(`hgvsp_short`)

maf = mutations %>%
  mutate(`maf` = t_alt_count / t_depth) %>%
  group_by(`sample_id`) %>%
  mutate(
    `median_maf` = median(`maf`),
    `mutation_count` = n()
    ) %>%
  ungroup() %>%
  filter(
    `hugo_symbol` == 'BRAF',
    `hgvsp_short` %in% relevant_variants
    ) %>%
  left_join(classes, by = 'hgvsp_short') %>%
  mutate(
    `class` = ifelse(`class` %in% c('1', '2', '3'), `class`, 'Unknown'),
    `class` = factor(`class`, levels = c('1', '2', '3', 'Unknown'))
  ) %>% 
  mutate(`maf_difference` = `maf` - `median_maf`)
  

p1 = ggboxplot(
  maf,
  x = 'class',
  y = 'maf',
  xlab = 'Variant class',
  ylab = 'Mutant allele fraction',
  #color = 'class',
  palette = 'npg',
  #add = 'jitter',
  #ylim = c(0, 1)
  title = 'All cancer types'
) +
  stat_compare_means(
    method = 'wilcox', 
    ref.group = '1',
    label.y = 1,
    paired = F,
    label = 'p.format'
    )


p2 = ggboxplot(
  maf %>% filter(`cancer_type` == 'Non-Small Cell Lung Cancer'),
  x = 'class',
  y = 'maf',
  xlab = 'Variant class',
  ylab = 'Mutant allele fraction',
  #color = 'class',
  palette = 'npg',
  #add = 'jitter',
  title = 'Non-small cell lung cancer'
  #ylim = c(0, 1)
) +
  stat_compare_means(
    method = 'wilcox', 
    ref.group = '1',
    label.y = 1,
    paired = F,
    label = 'p.format'
  )

p = ggarrange(p1, p2, labels = c('A', 'B'), ncol= 2, nrow = 1, widths = c(.5, .5)) + 
  theme(plot.margin = margin(.5, .5, 7, .5, unit = 'inch'))
ggexport(p, filename = '../figure_4.pdf', width = 8.5, height = 11)

