#'
#' Prepare data
#'

library(tidyverse)


fix_names = function(s) str_replace(str_to_lower(s), ' ', '_')

# Load GENIE data
patients = read_tsv('../genie/data_clinical_patient.txt', comment = '#') %>%
  rename_with(fix_names)
samples = read_tsv('../genie/data_clinical_sample.txt', comment = '#') %>%
  rename_with(fix_names)
mutations = read_tsv('../genie/data_mutations_extended.txt', comment = '#') %>%
  rename_with(fix_names)
fusions = read_tsv('../genie/data_fusions.txt', comment = '#') %>%
  rename_with(fix_names)
#cnas = read_tsv('../genie/data_CNA.txt', comment = '#') %>%
#  rename_with(fix_names)

# Create cancer types table
cancer_types = samples %>%
  select(`cancer_type`, `cancer_type_detailed`) %>%
  group_by(`cancer_type`) %>%
  mutate(`cancer_type_count` = n()) %>%
  group_by(`cancer_type_detailed`, .add = T) %>%
  mutate(`cancer_type_detailed_count` = n()) %>%
  distinct(`cancer_type`, `cancer_type_detailed`, .keep_all = T) %>%
  ungroup() %>%
  arrange(-`cancer_type_count`, -`cancer_type_detailed_count`) %>%
  write_tsv('../tmp/cancer_types.txt')

# Create samples table
samples_combined = patients %>%
  right_join(samples) %>%
  filter(
    !is.na(`cancer_type`),
    !`cancer_type` %in% c('UNKNOWN', 'Other Cancer, NOS')
  ) %>% 
  write_tsv('../tmp/samples.txt')

# Create mutations table
mutations_combined = patients %>%
  right_join(samples) %>%
  right_join(mutations, by = c('sample_id' = 'tumor_sample_barcode')) %>%
  filter(
    !is.na(`cancer_type`),
    !`cancer_type` %in% c('UNKNOWN', 'Other Cancer, NOS')
  ) %>%
  select(
    `sample_id`, 
    `cancer_type`, 
    `cancer_type_detailed`, 
    `hugo_symbol`, 
    `variant_classification`,
    `protein_position`,
    `hgvsc`,
    `hgvsp`,
    `hgvsp_short`,
    `t_alt_count`,
    `t_depth` 
  ) %>%
  filter(
    `variant_classification` != 'Silent',
    !is.na(`hgvsp`)
  ) %>%
  write_tsv('../tmp/mutations.txt')

# Create fusions table
fusions_combined = patients %>%
  right_join(samples) %>%
  right_join(fusions, by = c('sample_id' = 'tumor_sample_barcode')) %>%
  filter(
    !is.na(`cancer_type`),
    !`cancer_type` %in% c('UNKNOWN', 'Other Cancer, NOS'),
    `hugo_symbol` == 'BRAF'
  ) %>%
  write_tsv('../tmp/fusions.txt')